@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from datetime import datetime
 
 
 class BaseData:
@@ -7,6 +8,14 @@ class BaseData:
         # the status of the response
         self.status = ResponseStatusData(data)
 
+    @staticmethod
+    def datetime_converter(datetime_string):
+        if datetime_string:
+            return datetime.strptime(
+                datetime_string,
+                '%d-%m-%Y %H:%M:%S.%f'
+            )
+
 
 class WrapperDataInterface(ABC):
 
@@ -34,9 +43,19 @@ class AddressData:
         self.cap: str = data.get('cap', '')
         self.city: str = data.get('city', '')
         self.city_code: str = data.get('cityCode', '')
-        self.city_code_istat: str = data.get('cityCodeIstat')
-        self.name: str = data.get('name')
-        self.number: str = data.get('number')
-        self.place_name: str = data.get('placeName')
-        self.province: str = data.get('province')
-        self.town: str = data.get('town')
+        self.city_code_istat: str = data.get('cityCodeIstat', '')
+        self.name: str = data.get('name', '')
+        self.number: str = data.get('number', '')
+        self.place_name: str = data.get('placeName', '')
+        self.province: str = data.get('province', '')
+        self.town: str = data.get('town', '')
+
+
+class KeyValueData:
+
+    def __init__(self, data):
+        self.key = data.get('key', '')
+        self.value = data.get('value', '')
+
+    def __repr__(self):
+        return f'{self.key}-{self.value}'
